#[non_exhaustive]pub struct CloudControlDeployment {
pub name: String,
pub target_resource_config: Option<TargetResourceConfig>,
pub target_resource: String,
pub cloud_control_metadata: Option<CloudControlMetadata>,
pub description: String,
pub deployment_state: DeploymentState,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub parameter_substituted_cloud_control: Option<CloudControl>,
pub framework_deployment_references: Vec<FrameworkDeploymentReference>,
pub target_resource_display_name: String,
/* private fields */
}Expand description
A cloud control deployment represents the deployment of a particular cloud
control on a target resource. Supported target resources are
organizations/{organizationID}, folders/{folderID}, and
projects/{projectID}.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name for the cloud control deployment, in the format
organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}
or
projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}.
The only supported location is global.
target_resource_config: Option<TargetResourceConfig>Required. The details of the target resource that the cloud control is deployed You can use an existing target resource or create a new target.
target_resource: StringOutput only. The resource that the cloud control is deployed on, in one of the following formats:
organizations/{organizationID}folders/{folderID}projects/{projectID}
cloud_control_metadata: Option<CloudControlMetadata>Required. The deployment mode and parameters for the cloud control.
description: StringOptional. A friendly description for the cloud control deployment.
deployment_state: DeploymentStateOutput only. The state of the cloud control deployment.
create_time: Option<Timestamp>Output only. The time when the resource was created.
update_time: Option<Timestamp>Output only. The time when the resource was last updated.
etag: StringOptional. To prevent concurrent updates from overwriting each other,
provide the etag when you update a cloud control deployment. You can also
provide the etag when you delete a cloud control deployment to help
ensure that you’re deleting the intended version of the
deployment.
parameter_substituted_cloud_control: Option<CloudControl>Output only. The cloud control after the given parameters are substituted.
framework_deployment_references: Vec<FrameworkDeploymentReference>Output only. The references to the framework deployments that this cloud control deployment is part of. A cloud control deployment can be part of multiple framework deployments.
target_resource_display_name: StringOutput only. The display name of the target resource.
Implementations
Sourceimpl CloudControlDeployment
impl CloudControlDeployment
Sourcepub fn set_target_resource_config<T>(self, v: T) -> Selfwhere
T: Into<TargetResourceConfig>,
pub fn set_target_resource_config<T>(self, v: T) -> Selfwhere
T: Into<TargetResourceConfig>,
Sets the value of target_resource_config.
Example
use google_cloud_cloudsecuritycompliance_v1::model::TargetResourceConfig;
let x = CloudControlDeployment::new().set_target_resource_config(TargetResourceConfig::default()/* use setters */);Sourcepub fn set_or_clear_target_resource_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetResourceConfig>,
pub fn set_or_clear_target_resource_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetResourceConfig>,
Sets or clears the value of target_resource_config.
Example
use google_cloud_cloudsecuritycompliance_v1::model::TargetResourceConfig;
let x = CloudControlDeployment::new().set_or_clear_target_resource_config(Some(TargetResourceConfig::default()/* use setters */));
let x = CloudControlDeployment::new().set_or_clear_target_resource_config(None::<TargetResourceConfig>);Sourcepub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of target_resource.
Example
let x = CloudControlDeployment::new().set_target_resource("example");Sourcepub fn set_cloud_control_metadata<T>(self, v: T) -> Selfwhere
T: Into<CloudControlMetadata>,
pub fn set_cloud_control_metadata<T>(self, v: T) -> Selfwhere
T: Into<CloudControlMetadata>,
Sets the value of cloud_control_metadata.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControlMetadata;
let x = CloudControlDeployment::new().set_cloud_control_metadata(CloudControlMetadata::default()/* use setters */);Sourcepub fn set_or_clear_cloud_control_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CloudControlMetadata>,
pub fn set_or_clear_cloud_control_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CloudControlMetadata>,
Sets or clears the value of cloud_control_metadata.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControlMetadata;
let x = CloudControlDeployment::new().set_or_clear_cloud_control_metadata(Some(CloudControlMetadata::default()/* use setters */));
let x = CloudControlDeployment::new().set_or_clear_cloud_control_metadata(None::<CloudControlMetadata>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = CloudControlDeployment::new().set_description("example");Sourcepub fn set_deployment_state<T: Into<DeploymentState>>(self, v: T) -> Self
pub fn set_deployment_state<T: Into<DeploymentState>>(self, v: T) -> Self
Sets the value of deployment_state.
Example
use google_cloud_cloudsecuritycompliance_v1::model::DeploymentState;
let x0 = CloudControlDeployment::new().set_deployment_state(DeploymentState::Validating);
let x1 = CloudControlDeployment::new().set_deployment_state(DeploymentState::Creating);
let x2 = CloudControlDeployment::new().set_deployment_state(DeploymentState::Deleting);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = CloudControlDeployment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = CloudControlDeployment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = CloudControlDeployment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = CloudControlDeployment::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = CloudControlDeployment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = CloudControlDeployment::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_parameter_substituted_cloud_control<T>(self, v: T) -> Selfwhere
T: Into<CloudControl>,
pub fn set_parameter_substituted_cloud_control<T>(self, v: T) -> Selfwhere
T: Into<CloudControl>,
Sets the value of parameter_substituted_cloud_control.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControl;
let x = CloudControlDeployment::new().set_parameter_substituted_cloud_control(CloudControl::default()/* use setters */);Sourcepub fn set_or_clear_parameter_substituted_cloud_control<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<CloudControl>,
pub fn set_or_clear_parameter_substituted_cloud_control<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<CloudControl>,
Sets or clears the value of parameter_substituted_cloud_control.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControl;
let x = CloudControlDeployment::new().set_or_clear_parameter_substituted_cloud_control(Some(CloudControl::default()/* use setters */));
let x = CloudControlDeployment::new().set_or_clear_parameter_substituted_cloud_control(None::<CloudControl>);Sourcepub fn set_framework_deployment_references<T, V>(self, v: T) -> Self
pub fn set_framework_deployment_references<T, V>(self, v: T) -> Self
Sets the value of framework_deployment_references.
Example
use google_cloud_cloudsecuritycompliance_v1::model::FrameworkDeploymentReference;
let x = CloudControlDeployment::new()
.set_framework_deployment_references([
FrameworkDeploymentReference::default()/* use setters */,
FrameworkDeploymentReference::default()/* use (different) setters */,
]);Sourcepub fn set_target_resource_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_target_resource_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of target_resource_display_name.
Example
let x = CloudControlDeployment::new().set_target_resource_display_name("example");Trait Implementations
Sourceimpl Clone for CloudControlDeployment
impl Clone for CloudControlDeployment
Sourcefn clone(&self) -> CloudControlDeployment
fn clone(&self) -> CloudControlDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CloudControlDeployment
impl Debug for CloudControlDeployment
Sourceimpl Default for CloudControlDeployment
impl Default for CloudControlDeployment
Sourcefn default() -> CloudControlDeployment
fn default() -> CloudControlDeployment
Sourceimpl Message for CloudControlDeployment
impl Message for CloudControlDeployment
Sourceimpl PartialEq for CloudControlDeployment
impl PartialEq for CloudControlDeployment
impl StructuralPartialEq for CloudControlDeployment