#[non_exhaustive]pub struct DeleteFrameworkDeploymentRequest {
pub name: String,
pub etag: String,
/* private fields */
}Expand description
The request message for [DeleteFrameworkDeployment][].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the framework deployment that you want to delete,
in the format
organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment}
or
projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}.
The only supported location is global.
etag: StringOptional. An opaque identifier for the current version of the resource.
If you provide this value, then it must match the existing value. If the
values don’t match, then the request fails with an
[ABORTED][google.rpc.Code.ABORTED] error.
If you omit this value, then the resource is deleted regardless of its
current etag value.
Implementations