#[non_exhaustive]pub struct FrameworkDeployment {
pub name: String,
pub target_resource_config: Option<TargetResourceConfig>,
pub computed_target_resource: String,
pub framework: Option<FrameworkReference>,
pub description: String,
pub cloud_control_metadata: Vec<CloudControlMetadata>,
pub deployment_state: DeploymentState,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub target_resource_display_name: String,
pub cloud_control_deployment_references: Vec<CloudControlDeploymentReference>,
/* private fields */
}Expand description
Framework deployments represent the assignment of a framework to a target resource. Supported target resources are organizations, folders, and projects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the framework deployment, in the format
organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment}
or
projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}.
The only supported location is global.
target_resource_config: Option<TargetResourceConfig>Required. The details of the target resource that you want to deploy the framework to. You can specify an existing resource, or create a new one.
computed_target_resource: StringOutput only. The target resource to deploy the framework to, in one the following formats:
organizations/{organizationID}folders/{folderID}projects/{projectID}
framework: Option<FrameworkReference>Required. A reference to the framework that you’re deploying.
description: StringOptional. A user-provided description of the framework deployment.
cloud_control_metadata: Vec<CloudControlMetadata>Required. The deployment mode and parameters for each of the cloud controls in the framework. Every cloud control in the framework includes metadata.
deployment_state: DeploymentStateOutput only. The state for the framework deployment.
create_time: Option<Timestamp>Output only. The time at which the resource was created.
update_time: Option<Timestamp>Output only. The time at which the resource last updated.
etag: StringOptional. To prevent concurrent updates from overwriting each other, always
provide the etag when you update a framework deployment. You can also
provide the etag when you delete a framework deployment, to help
ensure that you’re deleting the intended version of the
framework deployment.
target_resource_display_name: StringOutput only. The display name of the target resource.
cloud_control_deployment_references: Vec<CloudControlDeploymentReference>Output only. The references to the cloud control deployments. The reference includes all the cloud control deployments that are in the framework or in a cloud control group.
For example, if a framework deployment deploys two
cloud controls, cc-deployment-1 and cc-deployment-2, then the
references are:
{
cloud_control_deployment_reference: {
cloud_control_deployment:
"organizations/{organization}/locations/{location}/cloudControlDeployments/cc-deployment-1"
},
cloud_control_deployment_reference: {
cloud_control_deployment:
"organizations/{organization}/locations/{location}/cloudControlDeployments/cc-deployment-2"
}Implementations
Sourceimpl FrameworkDeployment
impl FrameworkDeployment
Sourcepub fn set_target_resource_config<T>(self, v: T) -> Selfwhere
T: Into<TargetResourceConfig>,
pub fn set_target_resource_config<T>(self, v: T) -> Selfwhere
T: Into<TargetResourceConfig>,
Sets the value of target_resource_config.
Example
use google_cloud_cloudsecuritycompliance_v1::model::TargetResourceConfig;
let x = FrameworkDeployment::new().set_target_resource_config(TargetResourceConfig::default()/* use setters */);Sourcepub fn set_or_clear_target_resource_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetResourceConfig>,
pub fn set_or_clear_target_resource_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetResourceConfig>,
Sets or clears the value of target_resource_config.
Example
use google_cloud_cloudsecuritycompliance_v1::model::TargetResourceConfig;
let x = FrameworkDeployment::new().set_or_clear_target_resource_config(Some(TargetResourceConfig::default()/* use setters */));
let x = FrameworkDeployment::new().set_or_clear_target_resource_config(None::<TargetResourceConfig>);Sourcepub fn set_computed_target_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_computed_target_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of computed_target_resource.
Example
let x = FrameworkDeployment::new().set_computed_target_resource("example");Sourcepub fn set_framework<T>(self, v: T) -> Selfwhere
T: Into<FrameworkReference>,
pub fn set_framework<T>(self, v: T) -> Selfwhere
T: Into<FrameworkReference>,
Sourcepub fn set_or_clear_framework<T>(self, v: Option<T>) -> Selfwhere
T: Into<FrameworkReference>,
pub fn set_or_clear_framework<T>(self, v: Option<T>) -> Selfwhere
T: Into<FrameworkReference>,
Sets or clears the value of framework.
Example
use google_cloud_cloudsecuritycompliance_v1::model::FrameworkReference;
let x = FrameworkDeployment::new().set_or_clear_framework(Some(FrameworkReference::default()/* use setters */));
let x = FrameworkDeployment::new().set_or_clear_framework(None::<FrameworkReference>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = FrameworkDeployment::new().set_description("example");Sourcepub fn set_cloud_control_metadata<T, V>(self, v: T) -> Self
pub fn set_cloud_control_metadata<T, V>(self, v: T) -> Self
Sets the value of cloud_control_metadata.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControlMetadata;
let x = FrameworkDeployment::new()
.set_cloud_control_metadata([
CloudControlMetadata::default()/* use setters */,
CloudControlMetadata::default()/* use (different) setters */,
]);Sourcepub fn set_deployment_state<T: Into<DeploymentState>>(self, v: T) -> Self
pub fn set_deployment_state<T: Into<DeploymentState>>(self, v: T) -> Self
Sets the value of deployment_state.
Example
use google_cloud_cloudsecuritycompliance_v1::model::DeploymentState;
let x0 = FrameworkDeployment::new().set_deployment_state(DeploymentState::Validating);
let x1 = FrameworkDeployment::new().set_deployment_state(DeploymentState::Creating);
let x2 = FrameworkDeployment::new().set_deployment_state(DeploymentState::Deleting);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = FrameworkDeployment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = FrameworkDeployment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FrameworkDeployment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = FrameworkDeployment::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = FrameworkDeployment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FrameworkDeployment::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_target_resource_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_target_resource_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of target_resource_display_name.
Example
let x = FrameworkDeployment::new().set_target_resource_display_name("example");Sourcepub fn set_cloud_control_deployment_references<T, V>(self, v: T) -> Self
pub fn set_cloud_control_deployment_references<T, V>(self, v: T) -> Self
Sets the value of cloud_control_deployment_references.
Example
use google_cloud_cloudsecuritycompliance_v1::model::CloudControlDeploymentReference;
let x = FrameworkDeployment::new()
.set_cloud_control_deployment_references([
CloudControlDeploymentReference::default()/* use setters */,
CloudControlDeploymentReference::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for FrameworkDeployment
impl Clone for FrameworkDeployment
Sourcefn clone(&self) -> FrameworkDeployment
fn clone(&self) -> FrameworkDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FrameworkDeployment
impl Debug for FrameworkDeployment
Sourceimpl Default for FrameworkDeployment
impl Default for FrameworkDeployment
Sourcefn default() -> FrameworkDeployment
fn default() -> FrameworkDeployment
Sourceimpl Message for FrameworkDeployment
impl Message for FrameworkDeployment
Sourceimpl PartialEq for FrameworkDeployment
impl PartialEq for FrameworkDeployment
impl StructuralPartialEq for FrameworkDeployment