#[non_exhaustive]pub struct GenerateFrameworkAuditScopeReportRequest {
pub scope: String,
pub report_format: Format,
pub compliance_framework: String,
/* private fields */
}Expand description
The request message for [GenerateFrameworkAuditScopeReport][].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope: StringRequired. The organization, folder or project for the audit report.
Supported formats are the following:
projects/{project_id}/locations/{location}folders/{folder_id}/locations/{location}organizations/{organization_id}/locations/{location}
report_format: FormatRequired. The format that the scope report bytes is returned in.
compliance_framework: StringRequired. The compliance framework that the scope report is generated for.
Implementations
Sourceimpl GenerateFrameworkAuditScopeReportRequest
impl GenerateFrameworkAuditScopeReportRequest
pub fn new() -> Self
Sourcepub fn set_report_format<T: Into<Format>>(self, v: T) -> Self
pub fn set_report_format<T: Into<Format>>(self, v: T) -> Self
Sets the value of report_format.
Example
ⓘ
use google_cloud_cloudsecuritycompliance_v1::model::generate_framework_audit_scope_report_request::Format;
let x0 = GenerateFrameworkAuditScopeReportRequest::new().set_report_format(Format::Odf);Sourcepub fn set_compliance_framework<T: Into<String>>(self, v: T) -> Self
pub fn set_compliance_framework<T: Into<String>>(self, v: T) -> Self
Sets the value of compliance_framework.
Example
ⓘ
let x = GenerateFrameworkAuditScopeReportRequest::new().set_compliance_framework("example");Trait Implementations
Sourceimpl Clone for GenerateFrameworkAuditScopeReportRequest
impl Clone for GenerateFrameworkAuditScopeReportRequest
Sourcefn clone(&self) -> GenerateFrameworkAuditScopeReportRequest
fn clone(&self) -> GenerateFrameworkAuditScopeReportRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GenerateFrameworkAuditScopeReportRequest
impl Default for GenerateFrameworkAuditScopeReportRequest
Sourcefn default() -> GenerateFrameworkAuditScopeReportRequest
fn default() -> GenerateFrameworkAuditScopeReportRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for GenerateFrameworkAuditScopeReportRequest
impl PartialEq for GenerateFrameworkAuditScopeReportRequest
Sourcefn eq(&self, other: &GenerateFrameworkAuditScopeReportRequest) -> bool
fn eq(&self, other: &GenerateFrameworkAuditScopeReportRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GenerateFrameworkAuditScopeReportRequest