#[non_exhaustive]pub struct GenerateFrameworkAuditScopeReportResponse {
pub name: String,
pub compliance_framework: String,
pub audit_report: Option<AuditReport>,
/* private fields */
}Expand description
The response message for [GenerateFrameworkAuditScopeReport][].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the audit report, in the format that was given in the request.
compliance_framework: StringRequired. The compliance framework that the audit scope report is generated for.
audit_report: Option<AuditReport>The set of options that the audit scope report is exported in.
Implementations
Sourceimpl GenerateFrameworkAuditScopeReportResponse
impl GenerateFrameworkAuditScopeReportResponse
pub fn new() -> Self
Sourcepub fn set_compliance_framework<T: Into<String>>(self, v: T) -> Self
pub fn set_compliance_framework<T: Into<String>>(self, v: T) -> Self
Sets the value of compliance_framework.
Example
ⓘ
let x = GenerateFrameworkAuditScopeReportResponse::new().set_compliance_framework("example");Sourcepub fn set_audit_report<T: Into<Option<AuditReport>>>(self, v: T) -> Self
pub fn set_audit_report<T: Into<Option<AuditReport>>>(self, v: T) -> Self
Sets the value of audit_report.
Note that all the setters affecting audit_report are mutually
exclusive.
Example
ⓘ
use google_cloud_cloudsecuritycompliance_v1::model::generate_framework_audit_scope_report_response::AuditReport;
let x = GenerateFrameworkAuditScopeReportResponse::new().set_audit_report(Some(AuditReport::ScopeReportContents(bytes::Bytes::from_static(b"example"))));Sourcepub fn scope_report_contents(&self) -> Option<&Bytes>
pub fn scope_report_contents(&self) -> Option<&Bytes>
The value of audit_report
if it holds a ScopeReportContents, None if the field is not set or
holds a different branch.
Sourcepub fn set_scope_report_contents<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_scope_report_contents<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of audit_report
to hold a ScopeReportContents.
Note that all the setters affecting audit_report are
mutually exclusive.
Example
ⓘ
let x = GenerateFrameworkAuditScopeReportResponse::new().set_scope_report_contents(bytes::Bytes::from_static(b"example"));
assert!(x.scope_report_contents().is_some());Trait Implementations
Sourceimpl Clone for GenerateFrameworkAuditScopeReportResponse
impl Clone for GenerateFrameworkAuditScopeReportResponse
Sourcefn clone(&self) -> GenerateFrameworkAuditScopeReportResponse
fn clone(&self) -> GenerateFrameworkAuditScopeReportResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GenerateFrameworkAuditScopeReportResponse
impl Default for GenerateFrameworkAuditScopeReportResponse
Sourcefn default() -> GenerateFrameworkAuditScopeReportResponse
fn default() -> GenerateFrameworkAuditScopeReportResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for GenerateFrameworkAuditScopeReportResponse
impl PartialEq for GenerateFrameworkAuditScopeReportResponse
Sourcefn eq(&self, other: &GenerateFrameworkAuditScopeReportResponse) -> bool
fn eq(&self, other: &GenerateFrameworkAuditScopeReportResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GenerateFrameworkAuditScopeReportResponse