#[non_exhaustive]pub struct ListFrameworkDeploymentsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
The request message for [ListFrameworkDeployments][].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the framework deployment, in the format
organizations/{organization}/locations/{location}.
The only supported location is global.
page_size: i32Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.
page_token: StringOptional. A token that identifies a page of results the server should return.
filter: StringOptional. The filter to be applied on the resource, as defined by AIP-160: Filtering.
order_by: StringOptional. The sort order for the results. The following values are supported:
namename desc
If you do not specify a value, then the results are not sorted.
Implementations
Sourceimpl ListFrameworkDeploymentsRequest
impl ListFrameworkDeploymentsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListFrameworkDeploymentsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self