#[non_exhaustive]pub struct ListFrameworkDeploymentsResponse {
pub framework_deployments: Vec<FrameworkDeployment>,
pub next_page_token: String,
/* private fields */
}Expand description
The response message for [ListFrameworkDeployments][].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.framework_deployments: Vec<FrameworkDeployment>The list of framework deployments.
next_page_token: StringA token that identifies the next page of results that the server should return.
Implementations
Sourceimpl ListFrameworkDeploymentsResponse
impl ListFrameworkDeploymentsResponse
pub fn new() -> Self
Sourcepub fn set_framework_deployments<T, V>(self, v: T) -> Self
pub fn set_framework_deployments<T, V>(self, v: T) -> Self
Sets the value of framework_deployments.
Example
ⓘ
use google_cloud_cloudsecuritycompliance_v1::model::FrameworkDeployment;
let x = ListFrameworkDeploymentsResponse::new()
.set_framework_deployments([
FrameworkDeployment::default()/* use setters */,
FrameworkDeployment::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListFrameworkDeploymentsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListFrameworkDeploymentsResponse
impl Clone for ListFrameworkDeploymentsResponse
Sourcefn clone(&self) -> ListFrameworkDeploymentsResponse
fn clone(&self) -> ListFrameworkDeploymentsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListFrameworkDeploymentsResponse
impl Default for ListFrameworkDeploymentsResponse
Sourcefn default() -> ListFrameworkDeploymentsResponse
fn default() -> ListFrameworkDeploymentsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListFrameworkDeploymentsResponse
impl PartialEq for ListFrameworkDeploymentsResponse
Sourcefn eq(&self, other: &ListFrameworkDeploymentsResponse) -> bool
fn eq(&self, other: &ListFrameworkDeploymentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListFrameworkDeploymentsResponse