#[non_exhaustive]pub struct TargetResourceCreationConfig {
pub resource_creation_config: Option<ResourceCreationConfig>,
/* private fields */
}Expand description
The configuration that’s required to create a target resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_creation_config: Option<ResourceCreationConfig>The configuration that’s required to create the target resource.
Implementations
Sourceimpl TargetResourceCreationConfig
impl TargetResourceCreationConfig
Sourcepub fn set_resource_creation_config<T: Into<Option<ResourceCreationConfig>>>(
self,
v: T,
) -> Self
pub fn set_resource_creation_config<T: Into<Option<ResourceCreationConfig>>>( self, v: T, ) -> Self
Sets the value of resource_creation_config.
Note that all the setters affecting resource_creation_config are mutually
exclusive.
Example
use google_cloud_cloudsecuritycompliance_v1::model::FolderCreationConfig;
let x = TargetResourceCreationConfig::new().set_resource_creation_config(Some(
google_cloud_cloudsecuritycompliance_v1::model::target_resource_creation_config::ResourceCreationConfig::FolderCreationConfig(FolderCreationConfig::default().into())));Sourcepub fn folder_creation_config(&self) -> Option<&Box<FolderCreationConfig>>
pub fn folder_creation_config(&self) -> Option<&Box<FolderCreationConfig>>
The value of resource_creation_config
if it holds a FolderCreationConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_folder_creation_config<T: Into<Box<FolderCreationConfig>>>(
self,
v: T,
) -> Self
pub fn set_folder_creation_config<T: Into<Box<FolderCreationConfig>>>( self, v: T, ) -> Self
Sets the value of resource_creation_config
to hold a FolderCreationConfig.
Note that all the setters affecting resource_creation_config are
mutually exclusive.
Example
use google_cloud_cloudsecuritycompliance_v1::model::FolderCreationConfig;
let x = TargetResourceCreationConfig::new().set_folder_creation_config(FolderCreationConfig::default()/* use setters */);
assert!(x.folder_creation_config().is_some());
assert!(x.project_creation_config().is_none());Sourcepub fn project_creation_config(&self) -> Option<&Box<ProjectCreationConfig>>
pub fn project_creation_config(&self) -> Option<&Box<ProjectCreationConfig>>
The value of resource_creation_config
if it holds a ProjectCreationConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_project_creation_config<T: Into<Box<ProjectCreationConfig>>>(
self,
v: T,
) -> Self
pub fn set_project_creation_config<T: Into<Box<ProjectCreationConfig>>>( self, v: T, ) -> Self
Sets the value of resource_creation_config
to hold a ProjectCreationConfig.
Note that all the setters affecting resource_creation_config are
mutually exclusive.
Example
use google_cloud_cloudsecuritycompliance_v1::model::ProjectCreationConfig;
let x = TargetResourceCreationConfig::new().set_project_creation_config(ProjectCreationConfig::default()/* use setters */);
assert!(x.project_creation_config().is_some());
assert!(x.folder_creation_config().is_none());Trait Implementations
Sourceimpl Clone for TargetResourceCreationConfig
impl Clone for TargetResourceCreationConfig
Sourcefn clone(&self) -> TargetResourceCreationConfig
fn clone(&self) -> TargetResourceCreationConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TargetResourceCreationConfig
impl Debug for TargetResourceCreationConfig
Sourceimpl Default for TargetResourceCreationConfig
impl Default for TargetResourceCreationConfig
Sourcefn default() -> TargetResourceCreationConfig
fn default() -> TargetResourceCreationConfig
impl StructuralPartialEq for TargetResourceCreationConfig